==> alg-alg-2.23.57-sources.jar: cn/com/duiba/nezha/alg/alg/constant/DPAConstant.java <==
package cn.com.duiba.nezha.alg.alg.constant;

/**
 * @author lijingzhe
 * @description
 * @date 2020/6/17
 */
public class DPAConstant {
    // 广告位下组件扶持阈值
    public static final double CONFIDENTREQUEST = 10;
    // 广告位下组件满足扶持召回概率
    public static final double PROB = 0.1;
    // 皮肤组件召回数量
    public static final int SKINTOPN = 10;
    public static final int SKINTAGN = 1;
    // 皮肤组件召回类型
    public static final int RECALLSKIN = 0;
    public static final int GLOBALRECALLSKIN = 1;
    // 奖品组件召回数量
    public static final int PRIZETOPN = 100;
    // 奖品组件召回类型
    public static final int RECALLPRIZE = 2;
    public static final int GLOBALRECALLPRIZE = 3;
    // 券奖品组件召回数量
    public static final int AD_PRIZETOPN = 20;
    // 券奖品组件召回类型
    public static final int RECALL_ADPRIZE = 12;
    public static final int GLOBAL_RECALL_ADPRIZE = 3;

    // 奖品组合（包含普通奖品和券）召回数量上限
    public static final int RECALL_PRIZE_GROUP_NUM = 10;

    // 主标题组件召回数量
    public static final int TITLETOPN = 1;
    // 主标题组件召回类型
    public static final int RECALLTITLE = 4;
    public static final int GLOBALRECALLTITLE = 5;
    // 副标题组件召回数量
    public static final int SUBTITLETOPN = 1;
    // 副标题组件召回类型
    public static final int RECALLSUBTITLE = 6;
    public static final int GLOBALRECALLSUBTITLE = 7;
    // 合规校验后召回组件数量
    public static final int TOPK = 50;
    // 合规校验后召回组件类型
    public static final int RECALLPACKAGE = 8;
    public static final int GLOBALRECALLPACKAGE = 9;
    // UCB全局探索系数
    public static final double GLOBAL_W = 0.1;
    // 冷启动接口组件活动投放比例
    public static final double PACKAGE_REC_RATE = 0.2;
    // 全局和广告位融合比例
    public static final double GLOBAL_MERGE_RATE = 0.5;


    // 4.1cvr广告位访问pv置信阈值
    public static final int SLOT_VISIT_PV = 100;
    public static final int APP_VISIT_PV = 100;
    public static final int GLOBAL_VISIT_PV = 100;
    public static final double SLOT_CONFIDENCE = 1;
    public static final double APP_CONFIDENCE = 0.9;
    public static final double GLOBAL_CONFIDENCE = 0.5;
}

==> alg-alg-2.24.44-sources.jar: cn/com/duiba/nezha/alg/alg/constant/DPAConstant.java <==
package cn.com.duiba.nezha.alg.alg.constant;

/**
 * @author lijingzhe
 * @description
 * @date 2020/6/17
 */
public class DPAConstant {
    // 广告位下组件扶持阈值
    public static final double CONFIDENTREQUEST = 10;
    // 广告位下组件满足扶持召回概率
    public static final double PROB = 0.1;
    // 皮肤组件召回数量
    public static final int SKINTOPN = 10;
    public static final int SKINTAGN = 1;
    // 皮肤组件召回类型
    public static final int RECALLSKIN = 0;
    public static final int GLOBALRECALLSKIN = 1;
    // 奖品组件召回数量
    public static final int PRIZETOPN = 100;
    // 奖品组件召回类型
    public static final int RECALLPRIZE = 2;
    public static final int GLOBALRECALLPRIZE = 3;
    // 券奖品组件召回数量
    public static final int AD_PRIZETOPN = 20;
    // 券奖品组件召回类型
    public static final int RECALL_ADPRIZE = 12;
    public static final int GLOBAL_RECALL_ADPRIZE = 3;

    // 奖品组合（包含普通奖品和券）召回数量上限
    public static final int RECALL_PRIZE_GROUP_NUM = 10;

    // 主标题组件召回数量
    public static final int TITLETOPN = 1;
    // 主标题组件召回类型
    public static final int RECALLTITLE = 4;
    public static final int GLOBALRECALLTITLE = 5;
    // 副标题组件召回数量
    public static final int SUBTITLETOPN = 1;
    // 副标题组件召回类型
    public static final int RECALLSUBTITLE = 6;
    public static final int GLOBALRECALLSUBTITLE = 7;
    // 合规校验后召回组件数量
    public static final int TOPK = 50;
    // 合规校验后召回组件类型
    public static final int RECALLPACKAGE = 8;
    public static final int GLOBALRECALLPACKAGE = 9;
    // UCB全局探索系数
    public static final double GLOBAL_W = 0.1;
    // 冷启动接口组件活动投放比例
    public static final double PACKAGE_REC_RATE = 0.2;
    // 全局和广告位融合比例
    public static final double GLOBAL_MERGE_RATE = 0.5;


    // 4.1cvr广告位访问pv置信阈值
    public static final int SLOT_VISIT_PV = 100;
    public static final int APP_VISIT_PV = 100;
    public static final int GLOBAL_VISIT_PV = 100;
    public static final double SLOT_CONFIDENCE = 1;
    public static final double APP_CONFIDENCE = 0.9;
    public static final double GLOBAL_CONFIDENCE = 0.5;


    // 随机扰动概率
    public static final double RESORT_ROULETTE_TOP1_WEIGHT = 0.9;


    //奖品标签类型ID
    public static final long PRIZE_TAG_XIANJINHONGBAO = 1615;
    public static final long PRIZE_TAG_3CSHUMA = 1611;
    public static final long PRIZE_TAG_HUAFEILIULIANG = 1616;

    // 常规活动缩放阈值
    public static final int RECALL_ZOOM_MIN_NUM = 10;


    //自动发券消耗默认比值
    public static final double DEFAULT_ZD_COST_RATIO = 0.645;
    public static final double DEFAULT_ZD_CTR_RATIO = 0.1;

    public static final double SLOT_ACT_NORMAL_UPPER_BOUND = 3.0;

    //返回拦截活动召回数量
    public static final int INTERCEPT_RECALL_TOPN = 30;
    public static final int INTERCEPT_RECALL_TOPK = 3;
    public static final double INTERCEPT_PROB = 0.01;
    //返回拦截置信访问次数
    public static final int INTERCEPT_SLOT_CONFIDENT_REQUEST = 100;
    public static final int INTERCEPT_APP_CONFIDENT_REQUEST = 200;
    public static final int INTERCEPT_GLOBAL_CONFIDENT_REQUEST = 1000;
    //返回拦截不同维度召回加权分
    public static final double INTERCEPT_SLOT_WEIGHT = 1.0;
    public static final double INTERCEPT_APP_WEIGHT = 0.6;
    public static final double INTERCEPT_GLOBAL_WEIGHT = 0.2;

}
